# encoding=utf-8
import email
import logging
from email.mime.text import MIMEText

from brunns.builder import Builder, a_string
from brunns.builder.internet import DomainBuilder

logger = logging.getLogger(__name__)


class EmailBuilder(Builder):
    username = a_string
    domain = DomainBuilder

    def build(self):
        return "{0}@{1}".format(self.username, self.domain)


class EmailMessageBuilder(Builder):
    to_name = a_string
    to_email_address = EmailBuilder
    from_name = a_string
    from_email_address = EmailBuilder
    subject = a_string
    body_text = a_string

    def build(self):
        message = MIMEText(self.body_text)
        message["To"] = email.utils.formataddr((self.to_name, self.to_email_address))
        message["From"] = email.utils.formataddr((self.from_name, self.from_email_address))
        message["Subject"] = self.subject
        return message



# encoding=utf-8
import logging

import pendulum

from brunns.builder import Builder, an_integer

logger = logging.getLogger(__name__)


class DateBuilder(Builder):
    target = pendulum.date
    year = lambda: an_integer(1, 9999)
    month = lambda: an_integer(1, 12)
    day = lambda: an_integer(1, 28)



# encoding=utf-8
import logging
import string

from furl import furl

from brunns.builder import Builder, a_string, an_integer, one_of

logger = logging.getLogger(__name__)


class DomainBuilder(Builder):
    subdomain = lambda: a_string(characters=string.ascii_lowercase)
    tld = lambda: one_of("com", "net", "dev", "co.uk", "gov.uk", "ng")

    def build(self):
        return "{0}.{1}".format(self.subdomain, self.tld)


class UrlBuilder(Builder):
    target = furl

    scheme = lambda: one_of("http", "https", "tcp", None)
    username = a_string
    password = a_string
    host = DomainBuilder
    port = lambda: an_integer(1, 65535)
    path = lambda: [a_string(), a_string()]
    query = lambda: {a_string(): a_string(), a_string(): a_string()}
    fragment = a_string
